# FiftyOne Brain: Production/Marketing

Tools for generating marketing material across the FiftyOne project.

This provides information on generating repeatable marketing material (graphs,
screenshots, etc) backed by code.

This is in `fiftyone-brain` instead of `fiftyone` because it may reference
experiment details with proprietary information that only exists in the brain.

## Contents

| Asset                    | Description                                                              |
| ------------------------ | ------------------------------------------------------------------------ |
| `shot_bdd_detections.py` | Snaps a screenshot of some BDD object detections loaded in the dashboard |
| `shot_neardups.py`       | Snaps a screenshot of the near-duplicates output from CIFAR-10           |
| `use_cases_code.md`      | Example code demonstrating common FiftyOne use cases                     |

## Copyright

Copyright 2017-2023, Voxel51, Inc.<br> voxel51.com
